﻿using KitchenRoot;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace WpfKitchen
{
	public class MultiNodeTypeTreeTest
	{

		private static MultiNodeTypeTreeTest _instance	= null;

		protected TreeNode	_root;

		public static MultiNodeTypeTreeTest Instance
		{
			get
			{
				if(_instance == null)
					_instance = new MultiNodeTypeTreeTest();

				return _instance;
			}
		}


		public static MultiNodeTypeTreeTest GetInstance()
		{
			return Instance;
		}


		public TreeNode Root
		{
			get {  return _root; }
		}

		private MultiNodeTypeTreeTest()
		{
			InitializeTestTree();
		}


		void InitializeTestTree()
		{
			_root	= new TreeNode(null, "Root", false, isExclusive: false);

			_root.Children	= ChildNodesTest(_root, 8, 0);
		}


		TreeNodeList ChildNodesTest(TreeNode parent, int numNodes, int level)
		{
			parent.Children	= new TreeNodeList();

			TreeNodeList	children	= parent.Children;

			AddChildNodes(parent, children, numNodes, level);

			if(numNodes <= 1)
				return children;

			// add sub tree items
			foreach(TreeNode node in parent.Children)
			{
				node.Children = ChildNodesTest(node, numNodes - 1, level + 1);
			}

			return children;
		}


		void AddChildNodes(TreeNode parent, TreeNodeList children, int numNodes, int level)
		{
			for(int n = 0; n < numNodes; n++)
			{
				if((n % 4) > 0)
					children.Add(NewExclusiveNode(parent,	"Radio option " + level.ToString() + " - " + n.ToString(), false));
					
				else
					children.Add(NewNode(parent,			"Check Option " + level.ToString() + " - " + n.ToString(), false));
			}
		}

		TreeNode NewExclusiveNode(TreeNode parent, string title, bool isSelected)
		{
			return new TreeNode(parent, title, isSelected, isExclusive: true);
		}

		TreeNode NewNode(TreeNode parent, string title, bool isSelected)
		{
			return new TreeNode(parent, title, isSelected, isExclusive: false);
		}

	}
}
