﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq.Expressions;
using System.Collections.Specialized;
using System.Collections;

namespace KitchenRoot
{
	public class XObjectListNotifier<T> : List<T>, INotifyPropertyChanged, INotifyCollectionChanged
	{
		public event PropertyChangedEventHandler			PropertyChanged;
		public event NotifyCollectionChangedEventHandler	CollectionChanged;

		public XObjectListNotifier() : base()
		{
		}
		
		protected void NotifyPropertyChanged<TProperty>(Expression<Func<TProperty>> property)
		{
			if (property == null || PropertyChanged == null)
				return;

			var expression = property.Body as MemberExpression;

			if (expression == null)
				return;

			string name = expression.Member.Name;	// property.Name;
			NotifyPropertyChanged(name);
		}

		protected void NotifyPropertyChanged(string property_name)
		{
			if( PropertyChanged == null || string.IsNullOrEmpty( property_name))
				return;

			PropertyChanged.Invoke( this, new PropertyChangedEventArgs( property_name));
		}

		protected void NotifyCollectionChanged( object sender)
		{
			if( CollectionChanged == null)
				return;

			NotifyCollectionReset( sender);
			CollectionChanged.Invoke( sender, new NotifyCollectionChangedEventArgs( NotifyCollectionChangedAction.Add, (IList) this));
		}


		protected void NotifyCollectionReset( object sender)
		{
			if( CollectionChanged == null)
				return;

			CollectionChanged.Invoke( sender, new NotifyCollectionChangedEventArgs( NotifyCollectionChangedAction.Reset));
		}


		
	}
}
